@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2003-2017  Craig Barratt
+#   Copyright (C) 2003-2020  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 4.1.2, released 30 Apr 2017.
+# Version 4.3.2, released 17 Feb 2020.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -213,7 +213,7 @@ sub HostLink
 {
     my($host) = @_;
     my($s);
-    if ( defined($Hosts->{$host}) || defined($Status{$host}) ) {
+    if ( defined($Hosts->{$host}) ) {
         $s = "<a href=\"$MyURL?host=${EscURI($host)}\">$host</a>";
     } else {
         $s = $host;
@@ -358,8 +358,11 @@ sub CheckPermission
     return 0 if ( $User eq "" && $Conf{CgiAdminUsers} ne "*"
 	       || $host ne "" && !defined($Hosts->{$host}) );
     if ( $Conf{CgiAdminUserGroup} ne "" ) {
-        my($n,$p,$gid,$mem) = getgrnam($Conf{CgiAdminUserGroup});
-        $Privileged ||= ($mem =~ /\b\Q$User\E\b/);
+        for ( split(/\s+/, $Conf{CgiAdminUserGroup}) ) {
+            my ($n, $p, $gid, $mem) = getgrnam($_);
+            $Privileged ||= ( $mem =~ /\b\Q$User\E\b/ );
+            last if ( $Privileged );
+        }
     }
     if ( $Conf{CgiAdminUsers} ne "" ) {
         $Privileged ||= ($Conf{CgiAdminUsers} =~ /\b\Q$User\E\b/);
@@ -457,7 +460,7 @@ sub Header
     );
     my $host = $In{host};
 
-    binmode(STDOUT, ":utf8");
+    binmode(select, ":utf8");
     print $Cgi->header(-charset => "utf-8");
     print <<EOF;
 <!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
@@ -471,7 +474,7 @@ $Conf{CgiHeaders}
 
 <div id="navigation-container">
 	<div id="logo-container">
-		<a href="/"><img src="$Conf{CgiImageDirURL}/logo.gif"></a>
+		<a href="https://backuppc.github.io/backuppc/"><img src="$Conf{CgiImageDirURL}/logo.gif"></a>
 	</div>
 EOF
 
